@@ -1,5 +1,5 @@
 const t = require('tap')
-const mm = require('../')
+const mm = require('../').minimatch
 t.equal(mm('/a/b', '/*/b/x/y/z', { partial: true }), true)
 t.equal(mm('/a/b/c', '/*/b/x/y/z', { partial: true }), false)
 t.equal(mm('/', 'x', { partial: true }), true)
